@@ -24,7 +24,8 @@ import (
 	traitv1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1/trait"
 	"github.com/apache/camel-k/v2/pkg/trait"
 	"github.com/apache/camel-k/v2/pkg/util"
-	"k8s.io/utils/pointer"
+	corev1 "k8s.io/api/core/v1"
+	"k8s.io/utils/ptr"
 )
 
 // The Google Secret Manager trait can be used to use secrets from Google Secret Manager
@@ -41,7 +42,10 @@ import (
 // the following trait options:
 // -t gpc-secret-manager.enabled=true -t gpc-secret-manager.project-id="project-id" -t gpc-secret-manager.service-account-key="file:serviceaccount.json" -t gcp-secret-manager.subscription-name="pubsub-sub" -t gcp-secret-manager.context-reload-enabled="true" -t gcp-secret-manager.refresh-enabled="true" -t gcp-secret-manager.refresh-period="30000" -t gcp-secret-manager.secrets="test*"
 //
+// WARNING: The trait is **deprecated** and will removed in future release versions: configure directly the Camel properties as required by the component instead.
+//
 // +camel-k:trait=gcp-secret-manager.
+// +camel-k:deprecated=2.5.0.
 type Trait struct {
 	traitv1.Trait `property:",squash"`
 	// Enables automatic configuration of the trait.
@@ -76,7 +80,7 @@ func NewGcpSecretManagerTrait() trait.Trait {
 }
 
 func (t *gcpSecretManagerTrait) Configure(environment *trait.Environment) (bool, *trait.TraitCondition, error) {
-	if environment.Integration == nil || !pointer.BoolDeref(t.Enabled, false) {
+	if environment.Integration == nil || !ptr.Deref(t.Enabled, false) {
 		return false, nil, nil
 	}
 
@@ -85,18 +89,27 @@ func (t *gcpSecretManagerTrait) Configure(environment *trait.Environment) (bool,
 	}
 
 	if t.UseDefaultInstance == nil {
-		t.UseDefaultInstance = pointer.Bool(false)
+		t.UseDefaultInstance = ptr.To(false)
 	}
 
 	if t.ContextReloadEnabled == nil {
-		t.ContextReloadEnabled = pointer.Bool(false)
+		t.ContextReloadEnabled = ptr.To(false)
 	}
 
 	if t.RefreshEnabled == nil {
-		t.RefreshEnabled = pointer.Bool(false)
+		t.RefreshEnabled = ptr.To(false)
 	}
 
-	return true, nil, nil
+	condition := trait.NewIntegrationCondition(
+		"GCPSecretManager",
+		v1.IntegrationConditionTraitInfo,
+		corev1.ConditionTrue,
+		trait.TraitConfigurationReason,
+		"GCPSecretManager trait is deprecated and may be removed in future version: "+
+			"configure directly the Camel properties as required by the component instead",
+	)
+
+	return true, condition, nil
 }
 
 func (t *gcpSecretManagerTrait) Apply(environment *trait.Environment) error {
