@@ -91,19 +91,11 @@ func TestKamelCLIPromote(t *testing.T) {
 			InstallOperatorWithConf(t, ctx, g, nsProd, operatorProdID, false, nil)
 			g.Eventually(PlatformPhase(t, ctx, nsProd), TestTimeoutMedium).Should(Equal(v1.IntegrationPlatformPhaseReady))
 
-			t.Run("no configmap in destination", func(t *testing.T) {
-				g.Expect(Kamel(t, ctx, "promote", "-n", nsDev, "promote-route", "--to", nsProd).Execute()).NotTo(Succeed())
-			})
-
 			// Prod content configmap
 			var cmData = make(map[string]string)
 			cmData["my-configmap-key"] = "I am production"
 			CreatePlainTextConfigmap(t, ctx, nsProd, "my-cm-promote", cmData)
 
-			t.Run("no secret in destination", func(t *testing.T) {
-				g.Expect(Kamel(t, ctx, "promote", "-n", nsDev, "promote-route", "--to", nsProd).Execute()).NotTo(Succeed())
-			})
-
 			// Prod secret
 			var secData = make(map[string]string)
 			secData["my-secret-key"] = "very top secret production"
@@ -143,10 +135,6 @@ func TestKamelCLIPromote(t *testing.T) {
 				g.Expect(IntegrationPodImage(t, ctx, nsProd, "promote-route")()).Should(Equal(IntegrationPodImage(t, ctx, nsDev, "promote-route")()))
 			})
 
-			t.Run("no kamelet in destination", func(t *testing.T) {
-				g.Expect(Kamel(t, ctx, "promote", "-n", nsDev, "timer-kamelet-usage", "--to", nsProd).Execute()).NotTo(Succeed())
-			})
-
 			t.Run("kamelet integration promotion", func(t *testing.T) {
 				g.Expect(CreateTimerKameletWithID(t, ctx, operatorProdID, nsProd, "my-own-timer-source")()).To(Succeed())
 				g.Expect(Kamel(t, ctx, "promote", "-n", nsDev, "timer-kamelet-usage", "--to", nsProd).Execute()).To(Succeed())
@@ -156,10 +144,6 @@ func TestKamelCLIPromote(t *testing.T) {
 				g.Expect(IntegrationPodImage(t, ctx, nsProd, "timer-kamelet-usage")()).Should(Equal(IntegrationPodImage(t, ctx, nsDev, "timer-kamelet-usage")()))
 			})
 
-			t.Run("no kamelet for binding in destination", func(t *testing.T) {
-				g.Expect(Kamel(t, ctx, "promote", "-n", nsDev, "kb-timer-source-to-log", "--to", nsProd).Execute()).NotTo(Succeed())
-			})
-
 			t.Run("binding promotion", func(t *testing.T) {
 				g.Expect(CreateTimerKameletWithID(t, ctx, operatorProdID, nsProd, "kb-timer-source")()).To(Succeed())
 				g.Expect(Kamel(t, ctx, "promote", "-n", nsDev, "kb-timer-source-to-log", "--to", nsProd).Execute()).To(Succeed())
