@@ -431,6 +431,25 @@ func IntegrationLogs(t *testing.T, ctx context.Context, ns, name string) func()
 	}
 }
 
+func LastIntegrationCronLogs(t *testing.T, ctx context.Context, ns, name string) func() string {
+	return func() string {
+		pod := LastIntegrationCronPod(t, ctx, ns, name)()
+		if pod == nil {
+			return ""
+		}
+
+		options := corev1.PodLogOptions{
+			TailLines: ptr.To(int64(100)),
+		}
+
+		if len(pod.Spec.Containers) > 1 {
+			options.Container = pod.Spec.Containers[0].Name
+		}
+
+		return Logs(t, ctx, ns, pod.Name, options)()
+	}
+}
+
 func OperatorLogs(t *testing.T, ctx context.Context, ns string) func() string {
 	return func() string {
 		pod := OperatorPod(t, ctx, ns)()
@@ -572,6 +591,20 @@ func IntegrationPod(t *testing.T, ctx context.Context, ns string, name string) f
 	}
 }
 
+func LastIntegrationCronPod(t *testing.T, ctx context.Context, ns string, name string) func() *corev1.Pod {
+	return func() *corev1.Pod {
+		pods := IntegrationPodsSucceeded(t, ctx, ns, name)()
+		if len(pods) == 0 {
+			return nil
+		}
+
+		sort.SliceStable(pods, func(i, j int) bool {
+			return pods[i].GetCreationTimestamp().Time.After(pods[j].GetCreationTimestamp().Time)
+		})
+		return &pods[0]
+	}
+}
+
 func IntegrationPodHas(t *testing.T, ctx context.Context, ns string, name string, predicate func(pod *corev1.Pod) bool) func() bool {
 	return func() bool {
 		pod := IntegrationPod(t, ctx, ns, name)()
@@ -602,6 +635,21 @@ func IntegrationPods(t *testing.T, ctx context.Context, ns string, name string)
 	}
 }
 
+func IntegrationPodsSucceeded(t *testing.T, ctx context.Context, ns string, name string) func() []corev1.Pod {
+	return func() []corev1.Pod {
+		pods := IntegrationPods(t, ctx, ns, name)
+
+		completedPods := []corev1.Pod{}
+		for _, pod := range pods() {
+			if pod.Status.Phase == corev1.PodSucceeded || pod.Status.Phase == corev1.PodFailed {
+				completedPods = append(completedPods, pod)
+			}
+		}
+
+		return completedPods
+	}
+}
+
 func IntegrationPodsNumbers(t *testing.T, ctx context.Context, ns string, name string) func() *int32 {
 	return func() *int32 {
 		i := int32(len(IntegrationPods(t, ctx, ns, name)()))
@@ -2675,7 +2723,7 @@ func CreateKameletWithID(t *testing.T, operatorID string, ctx context.Context, n
 			},
 		}
 
-		kamelet.SetOperatorID(operatorID)
+		v1.SetAnnotation(&kamelet.ObjectMeta, v1.OperatorIDAnnotation, operatorID)
 		return TestClient(t).Create(ctx, &kamelet)
 	}
 }
@@ -3096,3 +3144,17 @@ func DeleteCIProcessID() {
 func RandomizedSuffixName(name string) string {
 	return name + strings.ToLower(v2util.RandomString(5))
 }
+
+// DefaultOperatorSecurityContext to ensure a container with low privilege and limited permissions.
+func DefaultOperatorSecurityContext() *corev1.SecurityContext {
+	sc := corev1.SecurityContext{
+		RunAsNonRoot: ptr.To(true),
+		SeccompProfile: &corev1.SeccompProfile{
+			Type: corev1.SeccompProfileTypeRuntimeDefault,
+		},
+		AllowPrivilegeEscalation: ptr.To(false),
+		Capabilities:             &corev1.Capabilities{Drop: []corev1.Capability{"ALL"}},
+	}
+
+	return &sc
+}
