@@ -90,11 +90,16 @@ func (in *Integration) AllSources() []SourceSpec {
 		if len(in.Status.GeneratedSources) == 0 {
 			sources = append(sources, src)
 		} else {
+			found := false
 			for _, genSrc := range in.Status.GeneratedSources {
-				if src.Name != genSrc.Name {
-					sources = append(sources, src)
+				if src.Name == genSrc.Name {
+					found = true
+					break
 				}
 			}
+			if !found {
+				sources = append(sources, src)
+			}
 		}
 	}
 
@@ -150,6 +155,11 @@ func (in *Integration) IsManagedBuild() bool {
 	return err == nil && isManagedBuild
 }
 
+// IsGitBuild returns true when the Integration requires to be built from a Git repo.
+func (in *Integration) IsGitBuild() bool {
+	return in.Spec.Git != nil
+}
+
 func (in *IntegrationSpec) AddSource(name string, content string, language Language) {
 	in.Sources = append(in.Sources, NewSourceSpec(name, content, language))
 }
@@ -437,37 +447,37 @@ func (in *IntegrationStatus) RemoveCondition(condType IntegrationConditionType)
 	in.Conditions = newConditions
 }
 
-var _ ResourceCondition = IntegrationCondition{}
+var _ ResourceCondition = &IntegrationCondition{}
 
 func (in *IntegrationStatus) GetConditions() []ResourceCondition {
 	res := make([]ResourceCondition, 0, len(in.Conditions))
 	for _, c := range in.Conditions {
-		res = append(res, c)
+		res = append(res, &c)
 	}
 	return res
 }
 
-func (c IntegrationCondition) GetType() string {
+func (c *IntegrationCondition) GetType() string {
 	return string(c.Type)
 }
 
-func (c IntegrationCondition) GetStatus() corev1.ConditionStatus {
+func (c *IntegrationCondition) GetStatus() corev1.ConditionStatus {
 	return c.Status
 }
 
-func (c IntegrationCondition) GetLastUpdateTime() metav1.Time {
+func (c *IntegrationCondition) GetLastUpdateTime() metav1.Time {
 	return c.LastUpdateTime
 }
 
-func (c IntegrationCondition) GetLastTransitionTime() metav1.Time {
+func (c *IntegrationCondition) GetLastTransitionTime() metav1.Time {
 	return c.LastTransitionTime
 }
 
-func (c IntegrationCondition) GetReason() string {
+func (c *IntegrationCondition) GetReason() string {
 	return c.Reason
 }
 
-func (c IntegrationCondition) GetMessage() string {
+func (c *IntegrationCondition) GetMessage() string {
 	return c.Message
 }
 
