@@ -18,7 +18,6 @@ limitations under the License.
 package cmd
 
 import (
-	"bytes"
 	"context"
 	"os"
 	"testing"
@@ -27,15 +26,14 @@ import (
 	"github.com/apache/camel-k/v2/pkg/internal"
 	"github.com/spf13/cobra"
 	"github.com/spf13/viper"
+	"github.com/stretchr/testify/require"
 )
 
 func kamelTestPostAddCommandInit(t *testing.T, rootCmd *cobra.Command, options *RootCmdOptions) {
 	t.Helper()
 
 	err := kamelPostAddCommandInit(rootCmd, options.Flags)
-	if err != nil {
-		t.Fatalf("Unexpected error: %v", err)
-	}
+	require.NoError(t, err)
 }
 
 func kamelTestPreAddCommandInitWithClient(client client.Client) (*RootCmdOptions, *cobra.Command) {
@@ -56,37 +54,14 @@ func kamelTestPreAddCommandInit() (*RootCmdOptions, *cobra.Command) {
 
 func TestLoadFromEnvVar(t *testing.T) {
 	// shows how to include a "," character inside an env value see VAR1 value
-	if err := os.Setenv("KAMEL_RUN_ENVS", "\"VAR1=value,\"\"othervalue\"\"\",VAR2=value2"); err != nil {
-		t.Fatalf("Unexpected error: %v", err)
-	}
+	require.NoError(t, os.Setenv("KAMEL_RUN_ENVS", "\"VAR1=value,\"\"othervalue\"\"\",VAR2=value2"))
 
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	defer teardown(t, runCmdOptions.Flags)
 
 	_, err := ExecuteCommand(rootCmd, "run", "route.java")
-	if err != nil {
-		t.Fatalf("Unexpected error: %v", err)
-	}
-	if len(runCmdOptions.EnvVars) != 2 {
-		t.Fatalf("Properties expected to contain: \n %v elements\nGot:\n %v elemtns\n", 2, len(runCmdOptions.EnvVars))
-	}
-	if runCmdOptions.EnvVars[0] != "VAR1=value,\"othervalue\"" || runCmdOptions.EnvVars[1] != "VAR2=value2" {
-		t.Fatalf("EnvVars expected to be: \n %v\nGot:\n %v\n", "[VAR1=value,\"othervalue\" VAR=value2]", runCmdOptions.EnvVars)
-	}
-}
+	require.NoError(t, err)
 
-func TestLoadFromFile(t *testing.T) {
-	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
-
-	// shows how to include a "," character inside a property value see VAR1 value
-	propertiesFile := []byte(`kamel.run.envs: "VAR1=value,""othervalue""",VAR2=value2`)
-	runCmdOptions.Flags.SetConfigType("properties")
-	readViperConfigFromBytes(t, runCmdOptions.Flags, propertiesFile)
-
-	_, err := ExecuteCommand(rootCmd, "run", "route.java")
-	if err != nil {
-		t.Fatalf("Unexpected error: %v", err)
-	}
 	if len(runCmdOptions.EnvVars) != 2 {
 		t.Fatalf("Properties expected to contain: \n %v elements\nGot:\n %v elemtns\n", 2, len(runCmdOptions.EnvVars))
 	}
@@ -103,10 +78,6 @@ func TestPrecedenceEnvVarOverFile(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	defer teardown(t, runCmdOptions.Flags)
 
-	propertiesFile := []byte(`kamel.run.envs: VAR2=file`)
-	viper.SetConfigType("properties")
-	readViperConfigFromBytes(t, runCmdOptions.Flags, propertiesFile)
-
 	_, err := ExecuteCommand(rootCmd, "run", "route.java")
 	if err != nil {
 		t.Fatalf("Unexpected error: %v", err)
@@ -127,10 +98,6 @@ func TestPrecedenceCommandLineOverEverythingElse(t *testing.T) {
 	runCmdOptions, rootCmd, _ := initializeRunCmdOptions(t)
 	defer teardown(t, runCmdOptions.Flags)
 
-	propertiesFile := []byte(`kamel.run.envs: VAR2=file`)
-	viper.SetConfigType("properties")
-	readViperConfigFromBytes(t, runCmdOptions.Flags, propertiesFile)
-
 	_, err := ExecuteCommand(rootCmd, "run", "route.java", "--env", "VAR3=commandLine")
 	if err != nil {
 		t.Fatalf("Unexpected error: %v", err)
@@ -143,20 +110,10 @@ func TestPrecedenceCommandLineOverEverythingElse(t *testing.T) {
 	}
 }
 
-func readViperConfigFromBytes(t *testing.T, v *viper.Viper, propertiesFile []byte) {
-	t.Helper()
-
-	unexpectedErr := v.ReadConfig(bytes.NewReader(propertiesFile))
-	if unexpectedErr != nil {
-		t.Fatalf("Unexpected error: %v", unexpectedErr)
-	}
-}
-
 // We must ALWAYS clean the environment variables and viper library properties to avoid mess up with the rest of the tests.
 func teardown(t *testing.T, v *viper.Viper) {
 	t.Helper()
 	if err := os.Setenv("KAMEL_RUN_ENVS", ""); err != nil {
 		t.Fatalf("Unexpected error: %v", err)
 	}
-	readViperConfigFromBytes(t, v, make([]byte, 0))
 }
