@@ -31,7 +31,7 @@ import (
 
 	"golang.org/x/oauth2"
 
-	"github.com/google/go-github/v52/github"
+	"github.com/google/go-github/v72/github"
 )
 
 // Source represents the source file of an Integration.
@@ -84,7 +84,7 @@ func (s *Source) setContent(content []byte) error {
 	return nil
 }
 
-func (s Source) IsYaml() bool {
+func (s *Source) IsYaml() bool {
 	return strings.HasSuffix(s.Name, ".yaml") || strings.HasSuffix(s.Name, ".yml")
 }
 
