@@ -238,45 +238,6 @@ func enqueueRequestsFromConfigFunc(ctx context.Context, c client.Client, res ctr
 	return requests
 }
 
-func integrationProfileEnqueueRequestsFromMapFunc(ctx context.Context, c client.Client, profile *v1.IntegrationProfile) []reconcile.Request {
-	var requests []reconcile.Request
-
-	if profile.Status.Phase != v1.IntegrationProfilePhaseReady {
-		return requests
-	}
-
-	list := &v1.IntegrationList{}
-
-	// Do global search in case of global operator
-	var opts []ctrl.ListOption
-
-	if !platform.IsCurrentOperatorGlobal() {
-		opts = append(opts, ctrl.InNamespace(profile.Namespace))
-	}
-
-	if err := c.List(ctx, list, opts...); err != nil {
-		log.Error(err, "Failed to list integrations")
-		return requests
-	}
-
-	for i := range list.Items {
-		integration := list.Items[i]
-		if integration.Status.Phase == v1.IntegrationPhaseRunning && v1.GetIntegrationProfileAnnotation(&integration) == profile.Name {
-			if profileNamespace := v1.GetIntegrationProfileNamespaceAnnotation(&integration); profileNamespace == "" || profileNamespace == profile.Namespace {
-				log.Infof("IntegrationProfile %s changed, notify integration: %s", profile.Name, integration.Name)
-				requests = append(requests, reconcile.Request{
-					NamespacedName: types.NamespacedName{
-						Namespace: integration.Namespace,
-						Name:      integration.Name,
-					},
-				})
-			}
-		}
-	}
-
-	return requests
-}
-
 func integrationPlatformEnqueueRequestsFromMapFunc(ctx context.Context, c client.Client, p *v1.IntegrationPlatform) []reconcile.Request {
 	var requests []reconcile.Request
 
@@ -333,6 +294,7 @@ func add(ctx context.Context, mgr manager.Manager, c client.Client, r reconcile.
 					return !e.DeleteStateUnknown
 				},
 			}))
+
 	// Watch for all the resources
 	watchIntegrationResources(c, b)
 	// Watch for the CronJob conditionally
@@ -375,16 +337,6 @@ func watchIntegrationResources(c client.Client, b *builder.Builder) {
 				}
 				return integrationPlatformEnqueueRequestsFromMapFunc(ctx, c, p)
 			})).
-		// Watch for IntegrationProfile and enqueue requests for any integrations that references the profile
-		Watches(&v1.IntegrationProfile{},
-			handler.EnqueueRequestsFromMapFunc(func(ctx context.Context, a ctrl.Object) []reconcile.Request {
-				profile, ok := a.(*v1.IntegrationProfile)
-				if !ok {
-					log.Error(fmt.Errorf("type assertion failed: %v", a), "Failed to retrieve IntegrationProfile")
-					return []reconcile.Request{}
-				}
-				return integrationProfileEnqueueRequestsFromMapFunc(ctx, c, profile)
-			})).
 		// Watch for Configmaps or Secret used in the Integrations for updates
 		Watches(&corev1.ConfigMap{},
 			handler.EnqueueRequestsFromMapFunc(func(ctx context.Context, a ctrl.Object) []reconcile.Request {
@@ -433,7 +385,9 @@ func watchIntegrationResources(c client.Client, b *builder.Builder) {
 				}
 			})).
 		// Watch for the owned Deployments
-		Owns(&appsv1.Deployment{}, builder.WithPredicates(StatusChangedPredicate{}))
+		Owns(&appsv1.Deployment{}, builder.WithPredicates(StatusChangedPredicate{})).
+		// Watch for the owned Builds
+		Owns(&v1.Build{}, builder.WithPredicates(StatusChangedPredicate{}))
 }
 
 func watchCronJobResources(b *builder.Builder) {
@@ -525,6 +479,7 @@ func (r *reconcileIntegration) Reconcile(ctx context.Context, request reconcile.
 	actions := []Action{
 		NewPlatformSetupAction(),
 		NewInitializeAction(),
+		NewBuildAction(),
 		newBuildKitAction(),
 	}
 
