@@ -17,7 +17,7 @@ limitations under the License.
 
 package integrationplatform
 
-import "github.com/apache/camel-k/pkg/util/log"
+import "github.com/apache/camel-k/v2/pkg/util/log"
 
-// Log --
+// Log --.
 var Log = log.Log.WithName("controller").WithName("integrationplatform")
