@@ -18,6 +18,7 @@ limitations under the License.
 package trait
 
 import (
+	"fmt"
 	"os"
 
 	"k8s.io/utils/ptr"
@@ -79,6 +80,10 @@ func (t *environmentTrait) Apply(e *Environment) error {
 	envvar.SetVal(&e.EnvVars, envVarCamelKRuntimeVersion, e.Integration.Status.RuntimeVersion)
 	envvar.SetVal(&e.EnvVars, envVarMountPathConfigMaps, camel.ConfigConfigmapsMountPath)
 	envvar.SetVal(&e.EnvVars, envVarMountPathSecrets, camel.ConfigSecretsMountPath)
+	if e.CamelCatalog.GetRuntimeProvider() == v1.RuntimeProviderPlainQuarkus {
+		envvar.SetVal(&e.EnvVars, "QUARKUS_CONFIG_LOCATIONS",
+			fmt.Sprintf("%s/application.properties,%s/user.properties", camel.BasePath, camel.ConfDPath))
+	}
 
 	if ptr.Deref(t.ContainerMeta, true) {
 		envvar.SetValFrom(&e.EnvVars, envVarNamespace, "metadata.namespace")
@@ -102,7 +107,7 @@ func (t *environmentTrait) Apply(e *Environment) error {
 			k, v := property.SplitPropertyFileEntry(env)
 			confs := v1.PlainConfigSecretRegexp.FindAllStringSubmatch(v, -1)
 			if len(confs) > 0 {
-				var res, err = v1.DecodeValueSource(v, "", "Invalid configuration "+v)
+				var res, err = v1.DecodeValueSource(v, "")
 				if err != nil {
 					return err
 				}
