@@ -180,7 +180,7 @@ func (c *Catalog) executedTraitCondition(executedTrait []Trait) (*TraitCondition
 	}
 
 	message := fmt.Sprintf("Applied traits: %s", strings.Join(traitIds, ","))
-	c.L.Debugf(message)
+	c.L.Debug(message)
 
 	return NewIntegrationCondition("", v1.IntegrationConditionTraitInfo, corev1.ConditionTrue, TraitConfigurationReason, message), traits, nil
 }
