@@ -21,7 +21,6 @@ import (
 	"fmt"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
-	"github.com/apache/camel-k/v2/pkg/apis/camel/v1alpha1"
 	"github.com/go-logr/logr"
 	logf "sigs.k8s.io/controller-runtime/pkg/log"
 	"sigs.k8s.io/controller-runtime/pkg/log/zap"
@@ -165,17 +164,6 @@ func (l Logger) ForPipe(target *v1.Pipe) Logger {
 	)
 }
 
-// ForKameletBinding --.
-// Deprecated: use ForPipe instead.
-func (l Logger) ForKameletBinding(target *v1alpha1.KameletBinding) Logger {
-	return l.WithValues(
-		"api-version", target.APIVersion,
-		"kind", target.Kind,
-		"ns", target.Namespace,
-		"name", target.Name,
-	)
-}
-
 // ForCatalog --.
 func (l Logger) ForCatalog(target *v1.CamelCatalog) Logger {
 	return l.WithValues(
@@ -217,11 +205,6 @@ func ForIntegrationKit(target *v1.IntegrationKit) Logger {
 	return Log.ForIntegrationKit(target)
 }
 
-// ForIntegrationPlatform --.
-func ForIntegrationPlatform(target *v1.IntegrationPlatform) Logger {
-	return Log.ForIntegrationPlatform(target)
-}
-
 // ***********************************
 //
 //
