@@ -39,35 +39,41 @@ type Command struct {
 	project Project
 }
 
+// Do is in charge to execute a given Maven phase.
 func (c *Command) Do(ctx context.Context) error {
-	if err := generateProjectStructure(c.context, c.project); err != nil {
+	mvnCmd, err := c.mvnCmd(ctx)
+	if err != nil {
 		return err
 	}
+	mavenOptions, env := c.optionsFromEnv()
 
-	mvnCmd := ""
-	if c, ok := os.LookupEnv("MAVEN_CMD"); ok {
-		mvnCmd = c
-	}
+	cmd := exec.CommandContext(ctx, mvnCmd, c.context.AdditionalArguments...)
+	cmd.Dir = c.context.Path
+	cmd.Env = env
 
-	if mvnCmd == "" {
-		if e, ok := os.LookupEnv("MAVEN_WRAPPER"); (ok && e == "true") || !ok {
-			// Prepare maven wrapper helps when running the builder as Pod as it makes
-			// the builder container, Maven agnostic
-			if err := c.prepareMavenWrapper(ctx); err != nil {
-				return err
-			}
-		}
+	Log.WithValues("MAVEN_OPTS", mavenOptions).Infof("executing: %s", strings.Join(cmd.Args, " "))
+	return util.RunAndLog(ctx, cmd, LogHandler, LogHandler)
+}
 
-		mvnCmd = "./mvnw"
+// DoPom is in charge to generate the pom file.
+func (c *Command) DoPom(ctx context.Context) error {
+	return generateProjectPom(c.context, c.project)
+}
+
+// DoSettings is in charge to prepare the maven settings required for a maven project.
+func (c *Command) DoSettings(ctx context.Context) error {
+	if err := generateProjectSettings(c.context); err != nil {
+		return err
 	}
 
 	args := make([]string, 0)
 	args = append(args, c.context.AdditionalArguments...)
 
 	if c.context.LocalRepository != "" {
-		if _, err := os.Stat(c.context.LocalRepository); err == nil {
-			args = append(args, "-Dmaven.repo.local="+c.context.LocalRepository)
+		if _, err := os.Stat(c.context.LocalRepository); err != nil {
+			return err
 		}
+		args = append(args, "-Dmaven.repo.local="+c.context.LocalRepository)
 	}
 
 	settingsPath := filepath.Join(c.context.Path, "settings.xml")
@@ -91,25 +97,19 @@ func (c *Command) Do(ctx context.Context) error {
 		args = append(args, "-Dsettings.security="+settingsSecurityPath)
 	}
 
-	mavenOptions, env := c.optionsFromEnv()
-
-	cmd := exec.CommandContext(ctx, mvnCmd, args...)
-	cmd.Dir = c.context.Path
-	cmd.Env = env
-
-	Log.WithValues("MAVEN_OPTS", mavenOptions).Infof("executing: %s", strings.Join(cmd.Args, " "))
-
 	// generate maven file
-	if err := generateMavenContext(c.context.Path, args, mavenOptions); err != nil {
-		return err
+	if !c.context.SkipMavenConfigGeneration {
+		if err := generateMavenContext(c.context.Path, args, c.context.ExtraMavenOpts); err != nil {
+			return err
+		}
 	}
 
-	return util.RunAndLog(ctx, cmd, LogHandler, LogHandler)
+	return nil
 }
 
-func (c *Command) optionsFromEnv() (string, []string) {
+func (c *Command) optionsFromEnv() ([]string, []string) {
 	if len(c.context.ExtraMavenOpts) == 0 {
-		return "", nil
+		return nil, nil
 	}
 
 	var mavenOptions string
@@ -151,7 +151,30 @@ func (c *Command) optionsFromEnv() (string, []string) {
 		}
 	}
 
-	return mavenOptions, env
+	return c.context.ExtraMavenOpts, env
+}
+
+// mvnCmd prepares the maven wrapper on the maven project or just use any other maven command
+// driven by MAVEN_CMD and MAVEN_WRAPPER environment variables configuration.
+func (c *Command) mvnCmd(ctx context.Context) (string, error) {
+	mvnCmd := ""
+	if c, ok := os.LookupEnv("MAVEN_CMD"); ok {
+		mvnCmd = c
+	}
+
+	if mvnCmd == "" {
+		if e, ok := os.LookupEnv("MAVEN_WRAPPER"); (ok && e == "true") || !ok {
+			// Prepare maven wrapper helps when running the builder as Pod as it makes
+			// the builder container, Maven agnostic
+			if err := c.prepareMavenWrapper(ctx); err != nil {
+				return "", err
+			}
+		}
+
+		mvnCmd = "./mvnw"
+	}
+
+	return mvnCmd, nil
 }
 
 func NewContext(buildDir string) Context {
@@ -163,14 +186,15 @@ func NewContext(buildDir string) Context {
 }
 
 type Context struct {
-	Path                string
-	ExtraMavenOpts      []string
-	GlobalSettings      []byte
-	UserSettings        []byte
-	SettingsSecurity    []byte
-	AdditionalArguments []string
-	AdditionalEntries   map[string]interface{}
-	LocalRepository     string
+	SkipMavenConfigGeneration bool
+	Path                      string
+	ExtraMavenOpts            []string
+	GlobalSettings            []byte
+	UserSettings              []byte
+	SettingsSecurity          []byte
+	AdditionalArguments       []string
+	AdditionalEntries         map[string]interface{}
+	LocalRepository           string
 }
 
 func (c *Context) AddEntry(id string, entry interface{}) {
@@ -197,23 +221,23 @@ func (c *Context) AddSystemProperty(name string, value string) {
 	c.AddArgumentf("-D%s=%s", name, value)
 }
 
-func generateProjectStructure(context Context, project Project) error {
-	if err := util.WriteFileWithBytesMarshallerContent(context.Path, "pom.xml", &project); err != nil {
-		return err
-	}
+// generateProjectPom is in charge to generate the pom.xml of an "in-memory" Project type.
+func generateProjectPom(context Context, project Project) error {
+	return util.WriteFileWithBytesMarshallerContent(context.Path, "pom.xml", &project)
+}
 
+// generateProjectSettings is in charge to generate the settings for any following maven command execution.
+func generateProjectSettings(context Context) error {
 	if context.GlobalSettings != nil {
 		if err := util.WriteFileWithContent(filepath.Join(context.Path, "settings.xml"), context.GlobalSettings); err != nil {
 			return err
 		}
 	}
-
 	if context.UserSettings != nil {
 		if err := util.WriteFileWithContent(filepath.Join(context.Path, "user-settings.xml"), context.UserSettings); err != nil {
 			return err
 		}
 	}
-
 	if context.SettingsSecurity != nil {
 		if err := util.WriteFileWithContent(filepath.Join(context.Path, "settings-security.xml"), context.SettingsSecurity); err != nil {
 			return err
@@ -293,23 +317,24 @@ func ParseGAV(gav string) (Dependency, error) {
 	return dep, nil
 }
 
-// Create a MAVEN_CONTEXT file containing all arguments for a maven command.
-func generateMavenContext(path string, args []string, options string) error {
-	// TODO refactor maven code to avoid creating a file to pass command args
-	return util.WriteToFile(filepath.Join(path, "MAVEN_CONTEXT"), getMavenContext(args, options))
+// Create a .mvn/maven.config file containing all arguments for any follow up maven command.
+func generateMavenContext(path string, args, options []string) error {
+	return util.WriteFileWithContent(filepath.Join(path, ".mvn", "maven.config"), []byte(getMavenContext(args, options)))
 }
 
-func getMavenContext(args []string, options string) string {
-	commandArgs := make([]string, 0)
+func getMavenContext(args, options []string) string {
+	mavenContext := ""
 	for _, arg := range args {
-		if arg != "package" && len(strings.TrimSpace(arg)) != 0 {
-			commandArgs = append(commandArgs, strings.TrimSpace(arg))
+		arg = strings.TrimSpace(arg)
+		if arg != "package" && len(arg) != 0 {
+			mavenContext += fmt.Sprintf("%s\n", arg)
 		}
 	}
-
-	mavenContext := strings.Join(commandArgs, " ")
-	if options != "" {
-		mavenContext += " " + options
+	for _, opt := range options {
+		opt = strings.TrimSpace(opt)
+		if len(opt) != 0 {
+			mavenContext += fmt.Sprintf("%s\n", opt)
+		}
 	}
 
 	return mavenContext
