@@ -136,21 +136,6 @@ func ParseResource(item string) (*Config, error) {
 	return parse(item, ContentTypeData)
 }
 
-// ParseVolume will parse a volume and return a Config.
-func ParseVolume(item string) (*Config, error) {
-	configParts := strings.Split(item, ":")
-
-	if len(configParts) != 2 {
-		return nil, fmt.Errorf("could not match pvc as %s", item)
-	}
-
-	return &Config{
-		storageType:     StorageTypePVC,
-		resourceName:    configParts[0],
-		destinationPath: configParts[1],
-	}, nil
-}
-
 // ParseConfig will parse a config and return a Config.
 func ParseConfig(item string) (*Config, error) {
 	return parse(item, ContentTypeText)
