@@ -18,12 +18,20 @@ limitations under the License.
 package source
 
 import (
-	"strings"
+	"fmt"
+	"regexp"
 
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/util"
 )
 
+var (
+	replaceURISingleQuotedFrom  = regexp.MustCompile(`from\s*\(\s*'(?:timer|cron|quartz)[^']*'\s*\)`)
+	replaceURISingleQuotedFromF = regexp.MustCompile(`fromF\s*\(\s*'(?:timer|cron|quartz)[^']*'\s*\)`)
+	replaceURIDoubleQuotedFrom  = regexp.MustCompile(`from\s*\(\s*"(?:timer|cron|quartz)[^"]*"\s*\)`)
+	replaceURIDoubleQuotedFromF = regexp.MustCompile(`fromF\s*\(\s*"(?:timer|cron|quartz)[^"]*"\s*\)`)
+)
+
 // GroovyInspector inspects Groovy DSL spec.
 type GroovyInspector struct {
 	baseInspector
@@ -61,25 +69,25 @@ func (i GroovyInspector) Extract(source v1.SourceSpec, meta *Metadata) error {
 
 // ReplaceFromURI parses the source content and replace the `from` URI configuration with the a new URI. Returns true if it applies a replacement.
 func (i GroovyInspector) ReplaceFromURI(source *v1.SourceSpec, newFromURI string) (bool, error) {
-	froms := util.FindAllDistinctStringSubmatch(
-		source.Content,
-		singleQuotedFrom,
-		doubleQuotedFrom,
-		singleQuotedFromF,
-		doubleQuotedFromF,
-	)
-	newContent := source.Content
-	if froms == nil {
-		return false, nil
-	}
-	for _, from := range froms {
-		newContent = strings.ReplaceAll(newContent, from, newFromURI)
-	}
-	replaced := newContent != source.Content
+	return replaceFromURI(source, newFromURI)
+}
 
-	if replaced {
-		source.Content = newContent
-	}
+func replaceFromURI(source *v1.SourceSpec, newFromURI string) (bool, error) {
+	originalContent := source.Content
 
-	return replaced, nil
+	source.Content = replaceURISingleQuotedFrom.ReplaceAllString(source.Content, fmt.Sprintf("from('%s')", newFromURI))
+	source.Content = replaceURISingleQuotedFromF.ReplaceAllString(source.Content, fmt.Sprintf("fromF('%s')", newFromURI))
+	source.Content = replaceURIDoubleQuotedFrom.ReplaceAllString(source.Content, fmt.Sprintf(`from("%s")`, newFromURI))
+	source.Content = replaceURIDoubleQuotedFromF.ReplaceAllString(source.Content, fmt.Sprintf(`fromF('%s')`, newFromURI))
+
+	return originalContent != source.Content, nil
+}
+
+func replaceFromURIDoubleQuotesOnly(source *v1.SourceSpec, newFromURI string) (bool, error) {
+	originalContent := source.Content
+
+	source.Content = replaceURIDoubleQuotedFrom.ReplaceAllString(source.Content, fmt.Sprintf(`from("%s")`, newFromURI))
+	source.Content = replaceURIDoubleQuotedFromF.ReplaceAllString(source.Content, fmt.Sprintf(`fromF('%s')`, newFromURI))
+
+	return originalContent != source.Content, nil
 }
