@@ -18,8 +18,6 @@ limitations under the License.
 package source
 
 import (
-	"strings"
-
 	v1 "github.com/apache/camel-k/v2/pkg/apis/camel/v1"
 	"github.com/apache/camel-k/v2/pkg/util"
 )
@@ -55,23 +53,5 @@ func (i KotlinInspector) Extract(source v1.SourceSpec, meta *Metadata) error {
 
 // ReplaceFromURI parses the source content and replace the `from` URI configuration with the a new URI. Returns true if it applies a replacement.
 func (i KotlinInspector) ReplaceFromURI(source *v1.SourceSpec, newFromURI string) (bool, error) {
-	froms := util.FindAllDistinctStringSubmatch(
-		source.Content,
-		doubleQuotedFrom,
-		doubleQuotedFromF,
-	)
-	newContent := source.Content
-	if froms == nil {
-		return false, nil
-	}
-	for _, from := range froms {
-		newContent = strings.ReplaceAll(newContent, from, newFromURI)
-	}
-	replaced := newContent != source.Content
-
-	if replaced {
-		source.Content = newContent
-	}
-
-	return replaced, nil
+	return replaceFromURIDoubleQuotesOnly(source, newFromURI)
 }
