@@ -28,9 +28,9 @@ target_tag=v$target_version
 target_staging=staging-$target_tag
 target_remote=$2
 
-# git add helm docs || true
-# git commit -m "chore(release): Helm chart for $target_version"
-# git push
+git add helm docs || true
+git commit -m "chore(release): Helm chart for $target_version"
+git push
 
 git branch -D ${target_staging} || true
 git checkout -b ${target_staging}
